[Scummvm-cvs-logs] CVS: scummvm/scumm script.cpp,1.236,1.237 script_v72he.cpp,2.317,2.318

kirben kirben at users.sourceforge.net
Thu Nov 17 02:50:00 CET 2005


Update of /cvsroot/scummvm/scummvm/scumm
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv29409/scumm

Modified Files:
	script.cpp script_v72he.cpp 
Log Message:

Update comments.


Index: script_v72he.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/script_v72he.cpp,v
retrieving revision 2.317
retrieving revision 2.318
diff -u -d -r2.317 -r2.318
--- script_v72he.cpp	16 Nov 2005 06:51:02 -0000	2.317
+++ script_v72he.cpp	17 Nov 2005 10:49:39 -0000	2.318
@@ -525,6 +525,8 @@
 }
 
 int ScummEngine_v72he::convertFilePath(byte *dst, bool setFilePath) {
+	debug(0, "convertFilePath: original filePath is %s", dst);
+
 	// Switch all \ to / for portablity
 	int len = resStrLen(dst) + 1;
 	for (int i = 0; i < len; i++) {





More information about the Scummvm-git-logs mailing list
Index: script.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/script.cpp,v
retrieving revision 1.236
retrieving revision 1.237
diff -u -d -r1.236 -r1.237
--- script.cpp	16 Nov 2005 05:14:46 -0000	1.236
+++ script.cpp	17 Nov 2005 10:49:39 -0000	1.237
@@ -583,14 +583,14 @@
 		checkRange(_numVariables - 1, 0, var, "Variable %d out of range(w)");
 
 		if (VAR_SUBTITLES != 0xFF && var == VAR_SUBTITLES) {
-			// Ignore default setting in HE60/61 games
-			if (_heversion >= 70 && vm.slot[_currentScript].number == 1)
+			// Ignore default setting in HE72-73 games
+			if (_heversion <= 73 && vm.slot[_currentScript].number == 1)
 				return;
 			assert(value == 0 || value == 1);
 			ConfMan.set("subtitles", value);
 		}
 		if (VAR_NOSUBTITLES != 0xFF && var == VAR_NOSUBTITLES) {
-			// Ignore default setting in HE60/61 games
+			// Ignore default setting in HE60-71 games
 			if (_heversion >= 60 && vm.slot[_currentScript].number == 1)
 				return;
 			assert(value == 0 || value == 1);
